{

  //make a new canvas
  TCanvas * cv = new TCanvas();

  ////**Preparing the histograms
  
  //make some fakedata
  TH1D * fakedata = new TH1D("fakedata","My fake data", 50,-4,4);
  fakedata->FillRandom("gaus");
  fakedata->SetLineColor(kRed);
  
  //make some fakeMC
  TH1D * fakeMC = new TH1D("fakeMC","My fake MC", 50,-4,4);
  fakeMC->FillRandom("landau");
  fakeMC->SetLineColor(kBlue);
  
  //make a THStack to hold them both
  THStack * stack = new THStack("dataAndMC", "dataAndMC");
  stack->Add(fakedata);
  stack->Add(fakeMC);
  //we need to Draw() to get the axis
  stack->Draw("A");
  stack->GetYaxis()->SetTitle("fake units");
 
  //let's take the relative difference 
  //of the two histograms to have an impression of data vs MC
  //(and let's hope some discrepancy this huge shows up at the LHC)
  
  //first of all, clone the numerator
  //as Add()/Divide() will overwrite the numerator
  TH1D* ratio = (TH1D*) fakedata->Clone();
  //subtract using the Add() function
  ratio->Add(fakeMC, -1);
  //normalise by MC using the Divide() function
  ratio->Divide(fakeMC);


  ////**Changing titles and labels
  
  ratio->GetYaxis()->SetTitle("[Data-MC]/MC");
  ratio->GetXaxis()->SetTitle("fake units");

  //ROOT will have titles and labels of size proportional
  //to the size of the pad  
  //all units below are proportional to size of pad
  //(but I've been lazy and didn't use this information)
  stack->GetYaxis()->SetLabelSize(0.06); 
  stack->GetYaxis()->SetTitleSize(0.07); 
  //Needed to display non-overlapping axis labels
  stack->GetYaxis()->SetTitleOffset(0.7); 
//   stack->SetMaximum(400); 
//   stack->SetMinimum(-10); 
  
  ratio->GetXaxis()->SetLabelSize(0.15);
  ratio->GetYaxis()->SetLabelSize(0.15); 
  ratio->GetYaxis()->SetTitleSize(0.17); 
  //Needed to display non-overlapping axis labels
  ratio->GetYaxis()->SetTitleOffset(0.27); 
  ratio->GetYaxis()->SetRangeUser(-3.5,3.5); 
  ratio->GetXaxis()->SetTitleOffset(0.7); 
  ratio->GetXaxis()->SetTitleSize(0.2); 

  //get a smaller number of labels for lack of space
  //see: http://root.cern.ch/root/html/TAttAxis.html
  //n = n1 + 100*n2 + 10000*n3
  // n1 is the number of primary divisions,
  // n2 is the number of second order divisions and
  // n3 is the number of third order divisions.
  ratio->GetYaxis()->SetNdivisions(504); 

  ////**Cleaning up

  //Clean up the canvas for the two pads
  cv->Clear();
  
  //remove all stat boxes/titles 
  //using the global variable gStyle
  gStyle->SetOptStat(0);
  gStyle->SetOptTitle(0);

  //snip: prepare two histograms to be displayed:
  //- stack (containing the fake data and fake MC)
  //- ratio (containing the ratio (data-MC)/MC)
  // and a TCanvas called cv
  
  ////**Making the pads
  
  //Set the coordinates of the current pad
  //xLow, yLow, xHigh, yHigh 
  pad1 = new TPad("pad1","pad1",0.05,0.30,1,1);
  pad2 = new TPad("pad2","pad2",0.05,0.05,1,0.30);
  pad1->SetTopMargin(0.02);
  pad1->SetLogy();
  pad2->SetTopMargin(0.0);
  pad1->SetBottomMargin(0.0);
  pad2->SetBottomMargin(0.30);
  pad1->Draw();
  pad2->Draw();
  pad1->cd();

  //now draw the histograms
  stack.Draw("nostack");
  //Update() is used to make the 
  //canvas realise something has happened
  cv->Update();
  pad2->cd();
  ratio->Draw();
  cv->Update();

  ////**Preparing the legend
  //draw it on the first pad
  pad1->cd();
  TLegend *l = new TLegend(0.4, 0.4, 0.6, 0.6);
  //let's make the legend background white
  l.SetFillColor(kWhite);
  //arguments: pointer to histogram, text, options: draw line (L)
  l.AddEntry(fakedata, "Fake data", "L");
  l.AddEntry(fakeMC, "Fake MC", "L");
  l.Draw("same");

}